==> react-pilot-0.1.5.tgz: package/lib/routeMatcher.js <==
import path from 'path'
import isArray from 'lodash/isArray'
import * as routeParser from './routeParser'
import getViewFromRoute from './getViewFromRoute'


export const findRoutes = (components, schemes = []) =>{
  const routes = new Map()
  components = isArray(components) ? components : [components];

  for (let component of components) {
    if (component.type === void 0)
      continue

    const parentPaths = schemes.map(s => s.props.path || '')
    const fullPath = path.join(...parentPaths, component.props.path || '')

    switch (component.type.displayName) {
      case 'Route':
      case 'Scheme':
        routes.set(fullPath, {name: component.props.name,
                              schemes: [...schemes],
                              component: component,
                              view: getViewFromRoute(component, schemes)})
        schemes.push(component)

        if (component.props.children) {
          const children = isArray(component.props.children) ?
                           component.props.children : [component.props.children]

          for (let [routePath, route] of findRoutes(children, schemes)) {
            routes.set(routePath, route)
          }
        }
        schemes.pop()
    }
  }
  return routes
}


/** Determines if a route matches a given path
  * @param {String} path
  * @returns {Array} [route text, matched args, matched named args]
  */
export const match = (route, urlPath) => {
  const pattern = routeParser.getPattern(route)
  const match = pattern.match.exec(urlPath)

  if (match) {
    const params = {}
    console.log(match, pattern.groups)
    for (let i = 1; i < match.length; i++) {
      const g = decodeURIComponent(match[i])
      const name = pattern.groups[i][1]
      console.log(name, g)
      if (name !== undefined && name !== null && name.length) {
        params[name] = g
      }
    }

    return [route, params]
  }
}

==> react-pilot-0.1.6.tgz: package/lib/routeMatcher.js <==
import path from 'path'
import isArray from 'lodash/isArray'
import * as routeParser from './routeParser'
import getViewFromRoute from './getViewFromRoute'


export const findRoutes = (components, schemes = []) =>{
  const routes = new Map()
  components = isArray(components) ? components : [components];

  for (let component of components) {
    if (component.type === void 0)
      continue

    const parentPaths = schemes.map(s => s.props.path || '')
    const fullPath = path.join(...parentPaths, component.props.path || '')

    switch (component.type.displayName) {
      case 'Route':
      case 'Scheme':
        routes.set(fullPath, {name: component.props.name,
                              schemes: [...schemes],
                              component: component,
                              view: getViewFromRoute(component, schemes)})
        schemes.push(component)

        if (component.props.children) {
          const children = isArray(component.props.children) ?
                           component.props.children : [component.props.children]

          for (let [routePath, route] of findRoutes(children, schemes)) {
            routes.set(routePath, route)
          }
        }
        schemes.pop()
    }
  }
  return routes
}


/** Determines if a route matches a given path
  * @param {String} path
  * @returns {Array} [route text, matched args, matched named args]
  */
export const match = (route, urlPath) => {
  const pattern = routeParser.getPattern(route)
  const match = pattern.match.exec(urlPath)

  if (match) {
    const params = {}
    console.log(match, pattern.groups)
    for (let i = 1; i < match.length; i++) {
      const g = decodeURIComponent(match[i])
      const name = pattern.groups[i - 1][1]
      console.log(name, g)
      if (name !== undefined && name !== null && name.length) {
        params[name] = g
      }
    }

    return [route, params]
  }
}
